package com.datacloudsec.scan.service.impl;

import com.datacloudsec.annotations.Transactional;
import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.DeviceMapper;
import com.datacloudsec.scan.dao.EngineMapper;
import com.datacloudsec.scan.dao.LogMapper;
import com.datacloudsec.scan.dao.SysBugMapper;
import com.datacloudsec.scan.dao.SysconfigMapper;
import com.datacloudsec.scan.dao.SysscanInfoMapper;
import com.datacloudsec.scan.dao.SystemTempMapper;
import com.datacloudsec.scan.dao.TaskMapper;
import com.datacloudsec.scan.entity.LicCmp;
import com.datacloudsec.scan.entity.Task;
import com.datacloudsec.scan.entity.User;
import com.datacloudsec.scan.service.IEngine;
import com.datacloudsec.scan.service.ITask;
import com.datacloudsec.scan.tasks.InitSystemTask;
import com.datacloudsec.scan.tasks.scheduler.job.AlermJob;
import com.datacloudsec.utils.ComonZipUtil;
import com.datacloudsec.utils.DataRule;
import com.datacloudsec.utils.IPUtil;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.JsonUtil;
import com.datacloudsec.utils.MybatisUtil;
import com.datacloudsec.utils.ObjectUtil;
import com.datacloudsec.utils.SerializeUtil;
import com.fasterxml.jackson.core.type.TypeReference;
import java.io.File;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpSession;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.ibatis.session.SqlSession;
import org.apache.log4j.Logger;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/TaskService.class */
public class TaskService extends TaskBaseService implements ITask {
    private TaskMapper taskMapper = (TaskMapper) InstanceUtil.newDaoInstance(TaskMapper.class);
    private DeviceMapper deviceMapper = (DeviceMapper) InstanceUtil.newDaoInstance(DeviceMapper.class);
    private SysBugMapper sysBugMapper = (SysBugMapper) InstanceUtil.newDaoInstance(SysBugMapper.class);
    private SystemTempMapper systemTempMapper = (SystemTempMapper) InstanceUtil.newDaoInstance(SystemTempMapper.class);
    private IEngine engine = new EngineService();
    private Logger LOG = Logger.getLogger(TaskService.class);
    private EngineMapper engineMapper = (EngineMapper) InstanceUtil.newDaoInstance(EngineMapper.class);
    private SysscanInfoMapper sysscanInfo = (SysscanInfoMapper) InstanceUtil.newDaoInstance(SysscanInfoMapper.class);
    private LogMapper logMapper = (LogMapper) InstanceUtil.newDaoInstance(LogMapper.class);
    private SysconfigMapper sysconfigMapper = (SysconfigMapper) InstanceUtil.newDaoInstance(SysconfigMapper.class);

    @Transactional
    public void delete(HttpSession session, Integer id, Integer version) throws Exception {
        int n = this.taskMapper.queryTaskDevCount((String) null, (Integer) null, 1, id).intValue();
        if (n > 0) {
            throw new UEException("该任务中有" + n + "个资产正在扫描，请先停止该任务中所有正在扫描的资产再删除！");
        }
        delTask(session, id, version);
    }

    public Integer insertSys(HttpSession session, String name, String desct, Integer type, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, String devList, String periodTime, String emailcheck, String smscheck, String confContent, Integer sysId, String warningType, Integer val1, Integer sysconfigId, String ftpReportType) throws Exception {
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        if (!cmp.contains("sysscan")) {
            throw new UEException("系统任务未授权");
        }
        LicCmp licCmp = getLicCp(cmp, "sysscan");
        if (InitSystemTask.licenseApp.valudate(licCmp.getAuthDay()) != 0) {
            throw new UEException("系统任务授权已过期");
        }
        User user = null;
        try {
            user = (User) session.getAttribute("userInfo");
            Integer count = this.taskMapper.getTaskCountByName(name, 1, user.getId(), (Integer) null);
            if (count != null && count.intValue() > 0) {
                throw new UEException("任务名称已存在！");
            }
        } catch (Exception e) {
            Integer count2 = this.taskMapper.getTcountForOthers(name, 1, (Integer) null);
            if (count2 != null && count2.intValue() > 0) {
                throw new UEException("任务名称已存在！");
            }
        }
        Integer taskid = add(null, name, desct, type, alarmMethod, alarmType, alarmTime, mailAddr, smsAddr, devList, periodTime, emailcheck, smscheck, null, 1, confContent, sysId, warningType, val1, sysconfigId, ftpReportType, session);
        if (type.intValue() == 1) {
            boolean bl = true;
            try {
                start(taskid);
            } catch (Exception e2) {
                bl = false;
                this.LOG.error("立即扫描异常出错", e2);
            }
            if (bl) {
                this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描主机任务", "", 1, "扫描成功");
            } else {
                this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描主机任务", "", 2, "扫描失败");
            }
        }
        startTimer(taskid, type, periodTime, alarmType, alarmMethod, alarmTime);
        return taskid;
    }

    private Integer add(Integer id, String name, String desct, Integer type, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, String devList, String periodTime, String emailcheck, String smscheck, Integer version, Integer taskType, String confContent, Integer sysId, String warningType, Integer val1, Integer sysconfigId, String ftpReportType, HttpSession session) throws Exception {
        String ip;
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        LicCmp licCmp = getLicCp(cmp, "sysscan");
        User user = (User) session.getAttribute("userInfo");
        int maxdevice = licCmp.getMaxdevice();
        String rule = DataRule.getRuleWhere(session, "t_task");
        Task task = new Task();
        task.setName(name);
        if (id != null) {
            task.setId(id);
        }
        task.setDesct(desct);
        task.setType(type);
        task.setAlarmMethod(alarmMethod);
        task.setAlarmType(alarmType);
        task.setAlarmTime(alarmTime);
        task.setMailAddr(emailcheck);
        task.setSmsAddr(smscheck);
        task.setPeriodTime(periodTime);
        if (user != null) {
            task.setUid(user.getId());
        }
        task.setTaskType(taskType);
        task.setVersion(version);
        task.setRule(rule);
        task.setConfContent(confContent);
        task.setSysId(sysId);
        task.setWarningType(warningType);
        task.setVal1(val1);
        task.setVal2(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
        task.setVal3(ObjectUtil.getString(devList, "", 65535));
        task.setSysconfigId(sysconfigId);
        task.setFtpReportType(ftpReportType);
        if (id != null) {
            task.setId(id);
        }
        if (id == null) {
            List<Map<String, Object>> devListMap = (List) JsonUtil.MAPPER_ESCAPE_HTML.readValue(devList, ArrayList.class);
            int devIpCount = 0;
            for (Map<String, Object> devMap : devListMap) {
                Map<String, Object> map = this.deviceMapper.getDevById(ObjectUtil.getInt(devMap.get("id")));
                if (map != null) {
                    ip = ObjectUtil.getString(map.get("ip"), "");
                } else {
                    ip = ObjectUtil.getString(devMap.get("name"), "");
                }
                if (user != null && ip.contains("*")) {
                    devIpCount += 254;
                    if (StringUtils.isNotBlank(user.getIps())) {
                        for (int i = 1; i <= 255; i++) {
                            String iptemp = ip.substring(0, ip.lastIndexOf("*"));
                            if (!IPUtil.ipVaild(String.valueOf(iptemp) + i, user.getIps())) {
                                throw new UEException("IP【" + ip + "】不在扫描范围内，可联系管理员授权扫描此IP");
                            }
                        }
                    } else {
                        continue;
                    }
                } else if (user != null && ip.contains("-")) {
                    String[] ipTmp = ip.split("-");
                    if (ipTmp[1].contains(".")) {
                        devIpCount += ObjectUtil.getInt(Long.valueOf(IPUtil.ipToLong(ipTmp[1]) - IPUtil.ipToLong(ipTmp[0])), 0);
                    } else if (ip.contains(":")) {
                        devIpCount += IPUtil.ipv6toInt(ipTmp[1]).subtract(IPUtil.ipv6toInt(ipTmp[0])).intValue();
                    } else {
                        devIpCount += ObjectUtil.getInt(Long.valueOf(IPUtil.ipToLong(String.valueOf(ipTmp[0].substring(0, ipTmp[0].lastIndexOf(".") + 1)) + ipTmp[1]) - IPUtil.ipToLong(ipTmp[0])), 0);
                        if (StringUtils.isNotBlank(user.getIps())) {
                            String iptemp2 = ip.substring(0, ip.lastIndexOf(".") + 1);
                            int start = ObjectUtil.getInt(ipTmp[0].substring(ipTmp[0].lastIndexOf(".") + 1, ipTmp[0].length()), 0);
                            for (int i2 = start; i2 < ObjectUtil.getInt(ipTmp[1], 0); i2++) {
                                if (!IPUtil.ipVaild(String.valueOf(iptemp2) + i2, user.getIps())) {
                                    throw new UEException("IP【" + ip + "】不在扫描范围内，可联系管理员授权扫描此IP");
                                }
                            }
                        } else {
                            continue;
                        }
                    }
                } else if (user != null && ip.contains("/")) {
                    devIpCount = !ip.contains(":") ? devIpCount + 65535 : devIpCount + ObjectUtil.getInt(Double.valueOf(Math.pow(2.0d, 32.0d - ObjectUtil.getDouble(ip.split("/")[1], 0.0d)) - 2.0d), 0);
                } else {
                    devIpCount++;
                    if (user != null && StringUtils.isNotBlank(user.getIps()) && !IPUtil.ipVaild(ip, user.getIps())) {
                        throw new UEException("IP【" + ip + "】不在扫描范围内，可联系管理员授权扫描此IP");
                    }
                }
            }
            if (maxdevice > 0 && devIpCount + this.taskMapper.getCountByType(ReportService.REPORT_STATE_READY) > maxdevice) {
                throw new UEException("当前资产数已达授权上限[" + maxdevice + "]");
            }
            this.taskMapper.insert(task);
            List<Map<String, Object>> devAuths = new ArrayList<>();
            List<String> devLists = new ArrayList<>();
            Map<String, Object> portMap = new HashMap<>();
            portMap.put("ssh", "22");
            portMap.put("telnet", "23");
            portMap.put("smb", "445");
            portMap.put("winrm", "5986");
            for (Map<String, Object> devMap2 : devListMap) {
                Map<String, Object> map2 = this.deviceMapper.getDevForSys(ObjectUtil.getInt(devMap2.get("id")));
                if (map2 != null) {
                    Map<String, Object> confMap = (Map) JsonUtil.MAPPER.readValue(ObjectUtil.getString(map2.get("confContent"), "{}"), HashMap.class);
                    Map<String, Object> authMap = (Map) JsonUtil.MAPPER.readValue(ObjectUtil.getString(map2.get("authContent"), "{}"), HashMap.class);
                    authMap.putAll((Map) confMap.get(ReportService.REPORT_STATE_READY));
                    authMap.put("ip", ObjectUtil.getString(map2.get("ip"), ""));
                    authMap.put("id", ObjectUtil.getInt(devMap2.get("id")));
                    if (ObjectUtil.getInt(authMap.get("port")) == null) {
                        authMap.put("port", portMap.get(ObjectUtil.getString(authMap.get("protocol"), "")));
                    }
                    devAuths.add(authMap);
                    devLists.add(ObjectUtil.getString(map2.get("ip"), ""));
                } else {
                    devLists.add(ObjectUtil.getString(devMap2.get("name"), ""));
                }
            }
            if (devLists != null && devLists.size() > 0) {
                this.sysscanInfo.setValue("sysscan_ip_" + task.getId(), StringUtils.join(devLists, ";"));
            }
            if (devAuths != null && devAuths.size() > 0) {
                this.sysscanInfo.setValue("sysscan_auth_" + task.getId(), JsonUtil.MAPPER.writeValueAsString(devAuths));
            }
        } else {
            Integer rcount = this.taskMapper.update(task);
            if (rcount != null && rcount.intValue() == 0) {
                throw new UEException("数据已被修改或删除，请刷新页面或返回");
            }
        }
        if (user != null) {
            if (StringUtils.isNotBlank(mailAddr)) {
                this.taskMapper.delEmail(user.getId());
                String[] mail = mailAddr.split(",");
                for (String ml : mail) {
                    this.taskMapper.insertEmail(ml, user.getId());
                }
            }
            if (StringUtils.isNotBlank(smsAddr)) {
                this.taskMapper.delPhone(user.getId());
                String[] sms = smsAddr.split(",");
                for (String s : sms) {
                    this.taskMapper.insertPhone(s, user.getId());
                }
            }
        }
        return task.getId();
    }

    public void insertTaskDev(Map<String, Object> map) throws Exception {
        this.taskMapper.insertTaskDevice(map);
    }

    public void updateSys(HttpSession session, Integer id, String name, String desct, Integer type, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, String periodTime, String emailcheck, String smscheck, Integer version, String confContent, Integer sysId, String warningType, Integer val1, Integer sysconfigId, String ftpReportType) throws Exception {
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.taskMapper.getTaskCountByName(name, 1, uid, id);
        if (count != null && count.intValue() > 0) {
            throw new UEException("任务名称已存在！");
        }
        add(id, name, desct, type, alarmMethod, alarmType, alarmTime, mailAddr, smsAddr, null, periodTime, emailcheck, smscheck, version, 1, confContent, sysId, warningType, val1, sysconfigId, ftpReportType, session);
        stopTimer(session, id);
        if (alarmType.intValue() == 2 || type.intValue() == 2) {
            startTimer(id, type, periodTime, alarmType, alarmMethod, alarmTime);
        }
    }

    public void startTask(Integer taskId) throws Exception {
        Task task = this.taskMapper.getTaskById(taskId);
        if (ObjectUtil.getInt(task.getStatus(), 0) == 1) {
            return;
        }
        if (StringUtils.isNotBlank(task.getVal3())) {
            List<Map<String, Object>> list = (List) JsonUtil.MAPPER.readValue(task.getVal3(), List.class);
            List<String> devLists = new ArrayList<>();
            for (Map<String, Object> map : list) {
                String ip = ObjectUtil.getString(map.get("name"), "");
                if (StringUtils.isNotBlank(ip)) {
                    devLists.add(ip);
                }
            }
            this.sysscanInfo.setValue("sysscan_ip_" + task.getId(), StringUtils.join(devLists, ";"));
        }
        SqlSession sqlSession2 = null;
        try {
            try {
                sqlSession2 = MybatisUtil.sqlSessionFactory.openSession();
                TaskMapper taskMapper = (TaskMapper) sqlSession2.getMapper(TaskMapper.class);
                taskMapper.delBugs2ByTaskId(task.getId());
                List<Map<String, Object>> sysBugs = taskMapper.getBugsByTaskId(task.getId());
                if (CollectionUtils.isNotEmpty(sysBugs)) {
                    taskMapper.copyBugsByTaskId(task.getId(), sysBugs);
                }
                sqlSession2.commit();
                if (sqlSession2 != null) {
                    sqlSession2.close();
                }
                SqlSession sqlSession = null;
                List<Map<String, Object>> devices = this.taskMapper.getTaskDevByTid(task.getId());
                for (Map<String, Object> dev : devices) {
                    try {
                        try {
                            Integer devid = ObjectUtil.getInt(dev.get("id"));
                            sqlSession = MybatisUtil.sqlSessionFactory.openSession();
                            SysBugMapper sysBugMapper = (SysBugMapper) sqlSession.getMapper(SysBugMapper.class);
                            TaskMapper taskMapper2 = (TaskMapper) sqlSession.getMapper(TaskMapper.class);
                            sysBugMapper.delBugByDevId(devid);
                            sysBugMapper.delSysHost(devid);
                            sysBugMapper.delSysErr(devid);
                            taskMapper2.delTaskDevById(devid);
                            sqlSession.commit();
                            if (sqlSession != null) {
                                sqlSession.close();
                            }
                        } catch (Exception e) {
                            sqlSession.rollback();
                            throw e;
                        }
                    } catch (Throwable th) {
                        if (sqlSession != null) {
                            sqlSession.close();
                        }
                        throw th;
                    }
                }
                start(taskId);
            } catch (Throwable th2) {
                if (sqlSession2 != null) {
                    sqlSession2.close();
                }
                throw th2;
            }
        } catch (Exception e2) {
            sqlSession2.rollback();
            throw e2;
        }
    }

    private void start(Integer taskid) throws Exception {
        Task task = this.taskMapper.getTaskById(taskid);
        if (task == null) {
            throw new UEException("此任务已被其它用户删除！");
        }
        if (ObjectUtil.getInt(task.getStatus(), 0) != 1) {
            Map<String, Object> sysconf = this.sysconfigMapper.getTemplateById(task.getSysconfigId());
            if (MapUtils.isNotEmpty(sysconf)) {
                task.setConfContent(ObjectUtil.getString(sysconf.get("config"), ""));
            }
            Map<String, String> taskOption = (Map) JsonUtil.MAPPER.readValue(task.getConfContent(), new TypeReference<Map<String, String>>() { // from class: com.datacloudsec.scan.service.impl.TaskService.1
            });
            Map<String, Object> sysPoliciy = this.systemTempMapper.getTemplateById(task.getSysId());
            if (sysPoliciy == null || sysPoliciy.size() == 0) {
                taskOption.put("plugin_set", "");
            } else if ("全部".equals(ObjectUtil.getString(sysPoliciy.get("name"), ""))) {
                taskOption.put("plugin_set", "");
            } else {
                taskOption.put("plugin_set", StringUtils.join(this.systemTempMapper.getMidPidByTmpid(task.getSysId()), ";"));
            }
            if (StringUtils.isNotBlank(taskOption.get("exclude_hosts"))) {
                taskOption.put("exclude_hosts", ObjectUtil.getString(taskOption.get("exclude_hosts"), "").replace("\n", ",").replace("`", ","));
            }
            taskOption.put("auths", this.sysscanInfo.getValueByName("sysscan_auth_" + task.getId()));
            try {
                Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
                boolean scanmode = ObjectUtil.getBoolean(params.get("scanmode"));
                if (!scanmode) {
                    taskOption.remove("scan_mode");
                }
                IEngine.EngineResult eresult = this.engine.sysScan(this.sysscanInfo.getValueByName("sysscan_ip_" + task.getId()), taskOption);
                if (eresult != null) {
                    task.setEngineId(eresult.getEngineId());
                    task.setLocalEid(Integer.valueOf(eresult.getLocalId()));
                    task.setOffset1(0);
                    task.setOffset2(0);
                    task.setOffset3(0);
                    task.setStatus(1);
                    task.setStartTime(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
                    task.setEndTime((String) null);
                    task.setScanCount(Integer.valueOf(ObjectUtil.getInt(task.getScanCount(), 0) + 1));
                    this.taskMapper.updateSysTask(task);
                    return;
                }
                task.setStatus(4);
                this.taskMapper.updateSysTask(task);
            } catch (Exception e) {
                String error = e instanceof UEException ? e.getMessage() : "连接引擎出错";
                task.setError(error);
                task.setStatus(3);
                this.taskMapper.updateSysTask(task);
                this.LOG.error("", e);
            }
        }
    }

    public void stop(Integer taskId) throws Exception {
        Task task = this.taskMapper.getTaskById(taskId);
        if (task == null) {
            throw new UEException("此任务已被其它用户删除！");
        }
        try {
            this.engine.sysStop(task.getEngineId(), task.getLocalEid().intValue());
        } catch (Exception e) {
            this.LOG.error("系统扫描（" + task.getId() + "）停止失败", e);
        }
        task.setStatus(0);
        this.taskMapper.updateSysTask(task);
        List<Map<String, Object>> devices = this.taskMapper.getTaskDevByTid(taskId);
        for (Map<String, Object> dev : devices) {
            Integer devid = ObjectUtil.getInt(dev.get("id"));
            dev.put("status", 0);
            dev.put("devid", devid);
            this.taskMapper.updateTaskDevice(dev);
            Map<String, Object> sys = this.sysBugMapper.bugCountByDev(devid);
            String sysIp = ObjectUtil.getString(dev.get("ip"), "");
            Date time = new Date();
            this.sysBugMapper.insertSysStatics(1, Integer.valueOf(ObjectUtil.getInt(sys.get("h"), 0)), time, devid, sysIp, task.getId());
            this.sysBugMapper.insertSysStatics(2, Integer.valueOf(ObjectUtil.getInt(sys.get("m"), 0)), time, devid, sysIp, task.getId());
            this.sysBugMapper.insertSysStatics(3, Integer.valueOf(ObjectUtil.getInt(sys.get("l"), 0)), time, devid, sysIp, task.getId());
            this.sysBugMapper.insertSysStatics(4, Integer.valueOf(ObjectUtil.getInt(sys.get("i"), 0)), time, devid, sysIp, task.getId());
            this.sysBugMapper.updDidByTidAndIp(devid, task.getId(), sysIp);
            Integer bugStaCount = this.sysBugMapper.bugStaCount();
            if (bugStaCount != null && bugStaCount.intValue() > 7) {
                this.sysBugMapper.delStatistics();
            }
        }
        if (task.getAlarmType().intValue() == 1) {
            AlermJob.alermTask(taskId);
        }
        Task waitingTask = this.engineMapper.getWaitingSysTask(1, taskId);
        if (waitingTask != null) {
            start(waitingTask.getId());
        }
    }

    public void delDev(Integer devId) throws Exception {
        Map<String, Object> webMap = this.taskMapper.getTaskDevById(devId);
        if (1 == ObjectUtil.getInt(webMap.get("status")).intValue()) {
            throw new UEException("正在扫描，请先停止后再删除！");
        }
        SqlSession session = null;
        try {
            try {
                session = MybatisUtil.sqlSessionFactory.openSession(true);
                SysBugMapper sysBugMapper = (SysBugMapper) session.getMapper(SysBugMapper.class);
                TaskMapper taskMapper = (TaskMapper) session.getMapper(TaskMapper.class);
                sysBugMapper.delBugByDevId(devId);
                sysBugMapper.delSysErr(devId);
                sysBugMapper.delSysHost(devId);
                sysBugMapper.clearStatistics(devId);
                taskMapper.delTaskDevById(devId);
                session.commit();
                if (session != null) {
                    session.close();
                }
            } catch (Exception e) {
                if (session != null) {
                    session.rollback();
                }
                throw e;
            }
        } catch (Throwable th) {
            if (session != null) {
                session.close();
            }
            throw th;
        }
    }

    public void addDev(String devIds, Integer taskId, User user) throws Exception {
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        LicCmp licCmp = getLicCp(cmp, "sysscan");
        int maxdevice = licCmp.getMaxdevice();
        String[] devIdArr = devIds.split(",");
        int devIpCount = 0;
        for (String devid : devIdArr) {
            Map<String, Object> map = this.deviceMapper.getDevById(ObjectUtil.getInt(devid));
            if (map != null) {
                devIpCount++;
            }
        }
        if (maxdevice > 0 && devIpCount + this.taskMapper.getCountByType(ReportService.REPORT_STATE_READY) > maxdevice) {
            throw new UEException("当前资产数已达授权上限[" + maxdevice + "]");
        }
        Task task = this.taskMapper.getTaskById(taskId);
        List<Map<String, Object>> devAuths = new ArrayList<>();
        List<String> devLists = new ArrayList<>();
        ArrayList arrayList = new ArrayList();
        for (String devid2 : devIdArr) {
            Map<String, Object> devMap = this.deviceMapper.getDevById(ObjectUtil.getInt(devid2));
            Map<String, Object> confMap = (Map) JsonUtil.MAPPER.readValue(ObjectUtil.getString(devMap.get("confContent"), "{}"), HashMap.class);
            Map<String, Object> authMap = (Map) JsonUtil.MAPPER.readValue(ObjectUtil.getString(devMap.get("authContent"), "{}"), HashMap.class);
            authMap.putAll((Map) confMap.get(ReportService.REPORT_STATE_READY));
            authMap.put("ip", ObjectUtil.getString(devMap.get("ip"), ""));
            authMap.put("id", ObjectUtil.getInt(devMap.get("id")));
            devAuths.add(authMap);
            devLists.add(ObjectUtil.getString(devMap.get("ip"), ""));
            HashMap hashMap = new HashMap();
            hashMap.put("name", ObjectUtil.getString(devMap.get("ip"), ""));
            arrayList.add(hashMap);
        }
        if (devLists != null && devLists.size() > 0) {
            if (StringUtils.isNotBlank(task.getVal3())) {
                List<Map<String, Object>> val3s = (List) JsonUtil.MAPPER.readValue(task.getVal3(), List.class);
                val3s.addAll(arrayList);
                task.setVal3(JsonUtil.MAPPER.writeValueAsString(val3s));
                this.taskMapper.update(task);
            }
            this.sysscanInfo.setValue("sysscan_ip_" + task.getId(), StringUtils.join(devLists, ";"));
        }
        if (devAuths != null && devAuths.size() > 0) {
            this.sysscanInfo.setValue("sysscan_auth_" + task.getId(), JsonUtil.MAPPER.writeValueAsString(devAuths));
        }
        if (task != null && task.getType().intValue() == 1) {
            boolean bl = true;
            try {
                start(task.getId());
            } catch (Exception e) {
                bl = false;
                this.LOG.error("扫描出错", e);
            }
            if (bl) {
                this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描主机任务", "", 1, "扫描成功");
            } else {
                this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描主机任务", "", 2, "扫描失败");
            }
        }
    }

    private void delTask(HttpSession session, Integer id, Integer version) throws Exception {
        Task task = this.taskMapper.getTaskById(id);
        try {
            this.engine.sysDelete(task.getEngineId(), task.getLocalEid().intValue());
        } catch (Exception e) {
            this.LOG.error("", e);
        }
        stopTimer(session, id);
        this.taskMapper.delTaskIpByTaskId(task.getId());
        this.taskMapper.delBugs2ByTaskId(task.getId());
        this.taskMapper.delBugsByTaskId(task.getId());
        this.taskMapper.delHostByTaskId(task.getId());
        this.taskMapper.clearSysSta(task.getId());
        this.taskMapper.clearSysErr(task.getId());
        this.taskMapper.delTaskDevByTid(id);
        this.sysscanInfo.delValue("sysscan_ip_" + task.getId());
        this.sysscanInfo.delValue("sysscan_auth_" + task.getId());
        Integer rcount = Integer.valueOf(this.taskMapper.delete(id, version, DataRule.getRuleWhere(session, "t_task")));
        if (rcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
    }

    public List<Map<String, Object>> getDevDetailByTid(Integer id, Integer offset, Integer limit) throws Exception {
        return this.taskMapper.getDevDetailByTid(id, offset, limit);
    }

    public List<Map<String, Object>> sysBugForDevice(Integer id) throws Exception {
        return this.taskMapper.sysBugForDevice(id);
    }

    public List<String> bugtimeForDevice(Integer id) throws Exception {
        return this.taskMapper.bugtimeForDevice(id);
    }

    public List<Map<String, Object>> bugPie(Integer id) throws Exception {
        return this.taskMapper.bugPie(id);
    }

    public List<Map<String, Object>> sysHostsByDevid(Integer id) throws Exception {
        return this.taskMapper.sysHostsByDevid(id);
    }

    public List<Map<String, Object>> sysBugTree(Integer id) throws Exception {
        return this.taskMapper.sysBugTree(id);
    }

    public List<Map<String, Object>> sysBugTreeInter(Integer id) throws Exception {
        return this.taskMapper.sysBugTreeInter(id);
    }

    public List<Map<String, Object>> newBug(Integer id) throws Exception {
        return this.taskMapper.newBug(id);
    }

    public List<Map<String, Object>> recovered(Integer id) throws Exception {
        return this.taskMapper.recovered(id);
    }

    public List<Map<String, Object>> sysErrByDevid(Integer id) throws Exception {
        return this.taskMapper.sysErrByDevid(id);
    }

    public Integer sysHostsCountByDevid(Integer id) throws Exception {
        return this.taskMapper.sysHostsCountByDevid(id);
    }

    public Integer sysErrCountByDevid(Integer id) throws Exception {
        return this.taskMapper.sysErrCountByDevid(id);
    }

    public Map<String, Object> getBugById(Integer id) throws Exception {
        return this.sysBugMapper.getBugById(id);
    }

    public int markBugErr(Integer id, Integer status) throws Exception {
        return this.taskMapper.markBugErr(id, status);
    }

    public void manualAddSys(HttpSession session, String ip, Integer taskId) throws Exception {
        if (taskId == null) {
            throw new UEException("任务ID不能为空");
        }
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        LicCmp licCmp = getLicCp(cmp, "sysscan");
        int maxdevice = licCmp.getMaxdevice();
        int devIpCount = 0;
        String[] ips = ip.split("\n");
        for (String iptemp : ips) {
            if (iptemp.contains("*")) {
                devIpCount += 254;
            } else if (iptemp.contains("-")) {
                String[] ipTmp = iptemp.split("-");
                if (ipTmp[1].contains(".")) {
                    devIpCount += ObjectUtil.getInt(Long.valueOf(IPUtil.ipToLong(ipTmp[1]) - IPUtil.ipToLong(ipTmp[0])), 0);
                } else {
                    devIpCount += ObjectUtil.getInt(Long.valueOf(IPUtil.ipToLong(String.valueOf(ipTmp[0].substring(0, ipTmp[0].lastIndexOf(".") + 1)) + ipTmp[1]) - IPUtil.ipToLong(ipTmp[0])), 0);
                }
            } else if (iptemp.contains("/")) {
                devIpCount += ObjectUtil.getInt(Double.valueOf(Math.pow(2.0d, 32.0d - ObjectUtil.getDouble(iptemp.split("/")[1], 0.0d)) - 2.0d), 0);
            } else {
                devIpCount++;
            }
        }
        if (maxdevice > 0 && devIpCount + this.taskMapper.getCountByType(ReportService.REPORT_STATE_READY) > maxdevice) {
            throw new UEException("当前资产数已达授权上限[" + maxdevice + "]");
        }
        Task task = this.taskMapper.getTaskById(taskId);
        List<Map<String, Object>> ipList = null;
        if (StringUtils.isNotBlank(task.getVal3())) {
            ipList = (List) JsonUtil.MAPPER.readValue(task.getVal3(), List.class);
        }
        List<String> devLists = new ArrayList<>();
        for (String iptemp2 : ips) {
            if (!StringUtils.isBlank(iptemp2)) {
                devLists.add(iptemp2);
                if (ipList != null) {
                    Map<String, Object> ipMap = new HashMap<>();
                    ipMap.put("name", iptemp2);
                    ipList.add(ipMap);
                }
            }
        }
        if (CollectionUtils.isNotEmpty(ipList)) {
            task.setVal3(JsonUtil.MAPPER.writeValueAsString(ipList));
            this.taskMapper.update(task);
        }
        if (CollectionUtils.isNotEmpty(devLists)) {
            this.sysscanInfo.setValue("sysscan_ip_" + task.getId(), StringUtils.join(devLists, ";"));
            if (task != null && task.getType().intValue() == 1) {
                User user = (User) session.getAttribute("userInfo");
                boolean bl = true;
                try {
                    start(task.getId());
                } catch (Exception e) {
                    bl = false;
                    this.LOG.error("扫描出错", e);
                }
                if (bl) {
                    this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描主机任务", "", 1, "扫描成功");
                } else {
                    this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描主机任务", "", 2, "扫描失败");
                }
            }
        }
    }

    public File sysBackup(Task t) throws Exception {
        File dir = new File(Constant.TEMP_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
        if (!dir.exists()) {
            dir.mkdirs();
        }
        File f = new File(Constant.TEMP_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
        try {
            SerializeUtil.serializeObj(new File(dir, "task.backup"), t);
            List<Map<String, Object>> devList = this.taskMapper.getTaskDevByTid(t.getId());
            for (Map<String, Object> dev : devList) {
                Integer devid = ObjectUtil.getInt(dev.get("id"));
                File devDir = new File(dir, new StringBuilder().append(devid).toString());
                if (!devDir.exists()) {
                    devDir.mkdirs();
                }
                SerializeUtil.serializeObj(new File(devDir, "dev.backup"), dev);
                SerializeUtil.serializeObj(new File(devDir, "bug.backup"), this.taskMapper.getBugByDevId(devid));
                SerializeUtil.serializeObj(new File(devDir, "bug2.backup"), this.taskMapper.getBug2ByDevId(devid));
                SerializeUtil.serializeObj(new File(devDir, "err.backup"), this.taskMapper.getErrByDevId(devid));
                SerializeUtil.serializeObj(new File(devDir, "host.backup"), this.taskMapper.getHostByDevId(devid));
                SerializeUtil.serializeObj(new File(devDir, "sta.backup"), this.taskMapper.getStaByDevId(devid));
                Map<String, Object> config = new HashMap<>();
                config.put("sysscan_ip_", this.sysscanInfo.getValueByName("sysscan_ip_" + t.getId()));
                config.put("sysscan_auth_", this.sysscanInfo.getValueByName("sysscan_auth_" + t.getId()));
                SerializeUtil.serializeObj(new File(devDir, "config.backup"), config);
            }
            ComonZipUtil.zip(dir.getPath(), f.getPath());
            if (dir != null && dir.exists()) {
                FileUtils.deleteDirectory(dir);
            }
            return f;
        } catch (Exception e) {
            throw e;
        }
    }

    @Transactional
    public void sysRestore(HttpSession session, File f) throws Exception {
        File unzipFile = new File(Constant.COMMON_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
        ComonZipUtil.unzip(f, unzipFile);
        File taskFile = new File(unzipFile, "task.backup");
        Task t = (Task) SerializeUtil.deserializeObj(taskFile);
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.taskMapper.getTaskCountByName(t.getName(), 1, uid, (Integer) null);
        if (count != null && count.intValue() > 0) {
            throw new UEException("sysTaskAlready:" + unzipFile.getName());
        }
        try {
            restore(unzipFile, t);
        } catch (Exception e) {
            FileUtils.deleteDirectory(unzipFile);
            throw e;
        }
    }

    private void restore(File unzipFile, Task t) throws Exception {
        Map<String, Object> device;
        if (unzipFile == null || t == null) {
            return;
        }
        this.taskMapper.insert(t);
        for (File taskDir : unzipFile.listFiles()) {
            if (!taskDir.getName().equals("task.backup") && (device = (Map) SerializeUtil.deserializeObj(new File(taskDir, "dev.backup"))) != null && device.size() != 0) {
                device.put("taskId", t.getId());
                this.taskMapper.inserTaskDevById(device);
                Integer devId = ObjectUtil.getInt(device.get("id"));
                List<Map<String, Object>> bugs = (List) SerializeUtil.deserializeObj(new File(taskDir, "bug.backup"));
                if (bugs != null && bugs.size() > 0) {
                    this.taskMapper.inserSysBugs(devId, t.getId(), bugs);
                }
                List<Map<String, Object>> bugs2 = (List) SerializeUtil.deserializeObj(new File(taskDir, "bug2.backup"));
                if (bugs2 != null && bugs2.size() > 0) {
                    this.taskMapper.inserSysBugs2(devId, t.getId(), bugs2);
                }
                List<Map<String, Object>> errs = (List) SerializeUtil.deserializeObj(new File(taskDir, "err.backup"));
                if (errs != null && errs.size() > 0) {
                    this.taskMapper.inserSysErr(devId, t.getId(), errs);
                }
                List<Map<String, Object>> hosts = (List) SerializeUtil.deserializeObj(new File(taskDir, "host.backup"));
                if (hosts != null && hosts.size() > 0) {
                    this.taskMapper.inserSysHost(devId, t.getId(), hosts);
                }
                List<Map<String, Object>> stas = (List) SerializeUtil.deserializeObj(new File(taskDir, "sta.backup"));
                if (stas != null && stas.size() > 0) {
                    this.taskMapper.inserSysSta(devId, t.getId(), stas);
                }
                Map<String, Object> config = (Map) SerializeUtil.deserializeObj(new File(taskDir, "config.backup"));
                if (config != null && config.size() > 0) {
                    String ipVal = ObjectUtil.getString(config.get("sysscan_ip_"), "");
                    if (!"".equals(ipVal)) {
                        this.sysscanInfo.setValue("sysscan_ip_" + t.getId(), ipVal);
                    }
                    String authVal = ObjectUtil.getString(config.get("sysscan_auth_"), "");
                    if (!"".equals(authVal)) {
                        this.sysscanInfo.setValue("sysscan_auth_" + t.getId(), authVal);
                    }
                }
            }
        }
        startTimer(t.getId(), t.getType(), t.getPeriodTime(), t.getAlarmType(), t.getAlarmMethod(), t.getAlarmTime());
        FileUtils.deleteDirectory(unzipFile);
    }

    @Transactional
    public void sysEnter(HttpSession session, String filename) throws Exception {
        File f = new File(Constant.COMMON_DIR, filename);
        if (f == null || !f.exists()) {
            this.LOG.error("系统恢复，文件不存在！");
            return;
        }
        User u = (User) session.getAttribute("userInfo");
        Task t = (Task) SerializeUtil.deserializeObj(new File(f, "task.backup"));
        t.setName(String.valueOf(t.getName()) + System.nanoTime());
        t.setUid(u.getId());
        try {
            restore(f, t);
        } catch (Exception e) {
            FileUtils.deleteDirectory(f);
            throw e;
        }
    }

    public int getDevCountByTid(Integer id) throws Exception {
        return this.taskMapper.getDevCountByTid(id);
    }

    public void mergeSysTask(String name, String desct, String taskids) throws Exception {
        String[] taskidarr = taskids.split(",");
        List<Map<String, Object>> taskDevs = this.taskMapper.getDevByTaskIds(taskidarr);
        if (CollectionUtils.isEmpty(taskDevs)) {
            throw new UEException("未发现要合并的任务资产");
        }
        Task task = this.taskMapper.getTaskById(ObjectUtil.getInt(taskidarr[0]));
        task.setName(name);
        task.setDesct(desct);
        task.setId((Integer) null);
        this.taskMapper.insert(task);
        Map<String, String> ipMap = new HashMap<>();
        for (Map<String, Object> taskDev : taskDevs) {
            try {
                Integer oldDevId = ObjectUtil.getInt(taskDev.get("id"));
                String ip = ObjectUtil.getString(taskDev.get("ip"), "");
                if (!ipMap.containsKey(ip)) {
                    ipMap.put(ip, ip);
                    taskDev.put("taskId", task.getId());
                    this.taskMapper.insertTaskDevice(taskDev);
                    Integer devid = ObjectUtil.getInt(taskDev.get("id"));
                    List<Map<String, Object>> stas = this.taskMapper.getStaByDevId(oldDevId);
                    if (CollectionUtils.isNotEmpty(stas)) {
                        this.taskMapper.inserSysSta(devid, task.getId(), stas);
                    }
                    List<Map<String, Object>> hosts = this.taskMapper.getHostByDevId(oldDevId);
                    if (CollectionUtils.isNotEmpty(hosts)) {
                        this.taskMapper.inserSysHost(devid, task.getId(), hosts);
                    }
                    List<Map<String, Object>> bugs = this.taskMapper.getBugByDevId(oldDevId);
                    if (CollectionUtils.isNotEmpty(bugs)) {
                        this.taskMapper.inserSysBugs(devid, task.getId(), bugs);
                    }
                    List<Map<String, Object>> errs = this.taskMapper.getErrByDevId(oldDevId);
                    if (CollectionUtils.isNotEmpty(errs)) {
                        this.taskMapper.inserSysErr(devid, task.getId(), errs);
                    }
                }
            } catch (Exception e) {
                this.LOG.error("", e);
            }
        }
    }
}
